/**
 * Simple AI Provider - Main Entry Point
 * 
 * A professional, extensible package for integrating multiple AI providers
 * into your applications with a unified interface.
 * 
 * @author Jan-Marlon Leibl
 * @version 1.0.0
 */

// Core types and interfaces
export type {
  AIProviderConfig,
  AIMessage,
  MessageRole,
  CompletionParams,
  CompletionResponse,
  CompletionChunk,
  TokenUsage,
  ProviderInfo
} from './types/index.js';

// Error handling
export { AIProviderError, AIErrorType } from './types/index.js';

// Base provider class
export { BaseAIProvider } from './providers/base.js';

// Concrete provider implementations
export { ClaudeProvider, type ClaudeConfig } from './providers/claude.js';
export { OpenAIProvider, type OpenAIConfig } from './providers/openai.js';

// Utility functions and factory
export {
  createProvider,
  createClaudeProvider,
  createOpenAIProvider,
  ProviderRegistry,
  type ProviderType,
  type ProviderConfigMap
} from './utils/factory.js';

// Re-export everything from providers for convenience
export * from './providers/index.js';

/**
 * Package version
 */
export const VERSION = '1.0.0';

/**
 * List of supported providers
 */
export const SUPPORTED_PROVIDERS = ['claude', 'openai'] as const; 